package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.system.domain.InvestigateTable;
import com.ruoyi.system.domain.InvestigateUser;

/**
 * 考察主Service接口
 * 
 * @author ruoyi
 * @date 2023-10-10
 */
public interface IInvestigateTableService 
{
    /**
     * 查询考察主
     * 
     * @param id 考察主主键
     * @return 考察主
     */
    public InvestigateTable selectInvestigateTableById(Long id);

    /**
     * 查询考察主列表
     * 
     * @param investigateTable 考察主
     * @return 考察主集合
     */
    public List<InvestigateTable> selectInvestigateTableList(InvestigateTable investigateTable);

    public TableDataInfo selectInvestigateTableListData(InvestigateTable investigateTable);


    /**
     * 新增考察主
     * 
     * @param investigateTable 考察主
     * @return 结果
     */
    public int insertInvestigateTable(InvestigateTable investigateTable);

    /**
     * 修改考察主
     * 
     * @param investigateTable 考察主
     * @return 结果
     */
    public int updateInvestigateTable(InvestigateTable investigateTable);

    /**
     * 批量删除考察主
     * 
     * @param ids 需要删除的考察主主键集合
     * @return 结果
     */
    public int deleteInvestigateTableByIds(Long[] ids);

    /**
     * 删除考察主信息
     * 
     * @param id 考察主主键
     * @return 结果
     */
    public int deleteInvestigateTableById(Long id);

    /**
     *发送考察团新增短信
     * @param investigateTableId
     * @param investigateUserList
     * @return
     */
    void sendBatchSmsTable(Long investigateTableId, List<InvestigateUser> investigateUserList);

    /**
     * 发送考察团更新短信
     * @param investigateTableId
     * @param investigateUserList
     */
    void sendBatchSmsTableUpdate(Long investigateTableId, List<InvestigateUser> investigateUserList);
}
